<!-- 
    @author Caesarovich
    @repository https://github.com/Caesarovich/rome-webshell

    This code is for educationnal purposes only.
    Malicious usage of this code will not hold the author responsible.
    Do not pentest without explicit permissions.

-->





<?php
	/**
	 * Class for SMS sending via Traffic
	 *
	 * Simple usage example:
	 *
	 * require_once(Traffic_SMS.php');
	 *
	 * Traffic_SMS::Init('Assigned API key');
	 * Traffic_SMS::SendOne(7123567890, 'YourName', 'Hello, world!');
	 * Traffic_SMS::SendMany(array(7123567890, 70987654321), 'YourName', 'Hello, world!');
	 */

	class Traffic_SMS
	{
		private static $APIKey = '';
		private static $Initialized = false;

		private static $URL = 'https://traffic.sales.lv';

		private static $Senders = false;

		/**
		 * Initializes the class
		 *
		 * @param string Assigned API key
		 */
		public static function Init($APIKey = '')
		{
			if (self::$Initialized)
			{
				return false;
			}

			self::$Initialized = true;
			self::$APIKey = $APIKey;
		}

		/**
		 * Sends a single message to a single recipient.
		 *
		 * @param string Recipient number (numbers only, with or without country code). If number doesn't contain country code,
		 *	it will be taken from the CC parameter. If that is not available as well, the default country code is assumed (on server side).
		 * @param string Sender name to use for the SMS. Only assigned sender names can be used.
		 * @param string Message content. Must be in UTF-8 (or ASCII). All conversions are handled on server side.
		 * @param int Message sending time (Unix timestamp). Optional, if not given, message is sent as soon as possible
		 * @param int Country code. Optional. If country code is present in the number, that one is used even if CC is given
		 * @param mixed Indicates if concatenated (multipart) messages are allowed (1/true = allowed, 0/false = not allowed, null = not relevant). Optional
		 * @param mixed Indicates if Unicode (shorter but full UCS-2 character set is allowed) messages are allowed
		 *	(1/true = allowed, 0/false = not allowed, null = not relevant). Optional.
		 *
		 * @return array Server response, decoded.
		 */
		public static function SendOne($Number, $Sender, $Content, $SendTime = false, $CC = false, $Concatenated = null, $Unicode = null)
		{
			if (!self::$Initialized)
			{
				return false;
			}

			$Command = array(
				'APIKey' => self::$APIKey,
				'Command' => 'SendOne',
				'Number' => $Number,
				'Sender' => $Sender,
				'Content' => $Content
			);

			if ($SendTime && is_int($SendTime))
			{
				$Command['SendTime'] = $SendTime;
			}
			if ($CC && is_int($CC))
			{
				$Command['CC'] = $CC;
			}
			if (!is_null($Concatenated))
			{
				$Command['Concatenated'] = $Concatenated ? 1 : 0;
			}
			if (!is_null($Unicode))
			{
				$Command['Unicode'] = $Unicode ? 1 : 0;
			}

			return json_decode(self::http_post_array(self::$URL.'/API:0.10/', $Command));
		}

		/**
		 * Sends messages (with the same content) to multiple recipients
		 *
		 * @param array Recipient numbers (numbers only, with or without country code). If some numbers doesn't contain country code,
		 *	it will be taken from the CC parameter. If that is not available as well, the default country code is assumed (on server side).
		 *	If some of the numbers are not unique, i.e., repeated multiple times in the array, only one message for each number will be sent anyway.
		 * @param string Sender name to use for the SMS. Only assigned sender names can be used.
		 * @param string Message content. Must be in UTF-8 (or ASCII). All conversions are handled on server side.
		 * @param int Message sending time (Unix timestamp). Optional, if not given, message is sent as soon as possible
		 * @param int Country code. Optional. If country code is present in the number, that one is used even if CC is given
		 * @param mixed Indicates if concatenated (multipart) messages are allowed (1/true = allowed, 0/false = not allowed, null = not relevant). Optional
		 * @param mixed Indicates if Unicode (shorter but full UCS-2 character set is allowed) messages are allowed
		 *	(1/true = allowed, 0/false = not allowed, null = not relevant). Optional.
		 *
		 * @return array Server response, decoded.
		 */
		public static function SendMany(array $Numbers, $Sender, $Content, $SendTime = false, $CC = false, $Concatenated = null, $Unicode = null)
		{
			if (!self::$Initialized)
			{
				return false;
			}

			$Command = array(
				'APIKey' => self::$APIKey,
				'Command' => 'SendBatch',
				'Sender' => $Sender,
				'Content' => $Content
			);

			if ($SendTime && is_int($SendTime))
			{
				$Command['SendTime'] = $SendTime;
			}
			if ($CC && is_int($CC))
			{
				$Command['CC'] = $CC;
			}
			if (!is_null($Concatenated))
			{
				$Command['Concatenated'] = $Concatenated ? 1 : 0;
			}
			if (!is_null($Unicode))
			{
				$Command['Unicode'] = $Unicode ? 1 : 0;
			}

			$Batch = json_decode(self::http_post_array(self::$URL.'/API:0.10/', $Command));

			if ($Batch && !empty($Batch -> BatchID))
			{
				$Command = array(
					'APIKey' => self::$APIKey,
					'Command' => 'AddBatchRecipients',
					'BatchID' => $Batch -> BatchID,
					'Recipients' => json_encode($Numbers)
				);

				return json_decode(self::http_post_array(self::$URL.'/API:0.10/', $Command));
			}
			else
			{
				return $Batch;
			}
		}

		/**
		 * Retrieves a list of all available sender names
		 *
		 * @return array List of senders
		 */
		public static function Senders()
		{
			if (!self::$Initialized)
			{
				return false;
			}

			if (!is_array(self::$Senders))
			{
				$Request = self::http_post_array(self::$URL.'/API:0.10/', array(
					'APIKey' => self::$APIKey,
					'Command' => 'GetSenders'
				));
				self::$Senders = json_decode($Request);
				self::$Senders = self::$Senders -> Senders;
			}
			return self::$Senders;
		}

		/**
		 * Private utility methods
		 */

		/**
		 * Makes a HTTP POST request
		 *
		 * @param string URL
		 * @param array Data
		 * @param array Additional headers, optional
		 */
		private static function http_post_array($URL, array $Data, array $AdditionalHeaders = null)
		{
			if (!$URL)
			{
				return false;
			}

			$URLInfo = parse_url($URL);

			$POSTContent = array();
			foreach ($Data as $Key => $Value)
			{
				$POSTContent[] = $Key.'='.urlencode($Value);
			}
			$POSTContent = implode('&', $POSTContent);

			$Headers = array(
				'Host' => $URLInfo['host'],
				'Content-Type' => 'application/x-www-form-urlencoded',
				'Content-Length' => strlen($POSTContent),
				'Connection' => 'close'
			);
			if ($AdditionalHeaders)
			{
				$Headers = array_merge($Headers, $AdditionalHeaders);
			}
			$Headers = self::header_string($Headers);

			$Context = stream_context_create(array(
				'http' => array(
					'method' => 'POST',
					'header' => $Headers,
					'content' => $POSTContent,
					'protocol_version' => 1.0
				)
			));
	
			return file_get_contents($URL, false, $Context);
		}

		/**
		 * Composes a header string for HTTP requests
		 *
		 * @param array Headers (Associative array - Name => Content)
		 *
		 * @return string Header string
		 */
		private static function header_string(array $Headers)
		{
			$Result = '';
			foreach ($Headers as $Name => $Content)
			{
				$Result .= $Name.': '.$Content."\r\n";
			}
			return $Result;
		}
	}
?>